from .__version__ import __title__, __description__, __url__, __version__, __author__, __author_email__, __license__, __copyright__
from randfacts.main import getFact, safeFacts, unsafeFacts, allFacts